# Fail Semantics

## Lack of proper support for injecting errors into classes that are already `Fail`
* Classes have only one implementation of `Fail` per error type.
* Proposed solutions:
  * Have `Fail` as a separate trait with the error and the class as associated types.
  * `OverloadClass` to mix-in additional `Fail`.

## ~~Lack of support for strict ordering of errors~~
* ~~Current (possible) implementations of having one error or another either allow short-circuiting on only one of them, or give them both the same priority. **Right now this model is considered the main one**, i.e. this restriction may get stabilised and standardised at some point.~~
* ~~More complex behaviours are expected to require a more complex execution model, with states taking messages from other states and optionally dropping their own execution, if their result\['s error\] is guaranteed to be "less severe" than the error it receives.~~
* Solution: `Fallible::W<E0>::F<Fallible::W<E1>::A>`.
* Another solution: native select-based approach, `ApplicativeSelect`.
